@@ -35,3 +35,7 @@ _SPIRV_OP_INTERNAL(ConvertHandleToSamplerINTEL,
                    internal::ConvertHandleToSamplerINTEL)
 _SPIRV_OP_INTERNAL(ConvertHandleToSampledImageINTEL,
                    internal::ConvertHandleToSampledImageINTEL)
+_SPIRV_OP_INTERNAL(PredicatedLoadINTEL,
+                   internal::OpPredicatedLoadINTEL)
+_SPIRV_OP_INTERNAL(PredicatedStoreINTEL,
+                   internal::OpPredicatedStoreINTEL)
